# ROI Tool

Created by Jan Kotanski, last modified on Jul 10, 2018 10:13

ROI Tool selects Regions Of Interest and culculates a sum of their pixel intensities

- ROI alias(es) for roi tango devices
- Add to or Fetch from sardana environment
- Sum of the selected ROI or all ROIs. The used version can be selected in the configuration.

Moreover, in configuration can be set if the sums of calculated ROIs should be sent to LavueController tango server.